pip: Tool for installing and managing Python packages
=====================================================

Description
-----------

This package installs pip, the tool for installing and managing Python
packages, such as those found in the Python Package Index. It’s a
replacement for easy_install.

License
-------

MIT


Upstream Contact
----------------

- Project Page: https://github.com/pypa/pip
- Install howto: https://pip.pypa.io/en/latest/installing.html
- Changelog: https://pip.pypa.io/en/latest/news.html
- Bug Tracking: https://github.com/pypa/pip/issues
- Mailing list: http://groups.google.com/group/python-virtualenv
- Docs: https://pip.pypa.io/

